@@ -56,7 +56,7 @@ static void create_toolbar( MainView *main );
 void create_textarea( MainView *main );
 GtkWidget *show_rec_line(GtkWidget *sizer, char *label, char *txt, int row, int col);
 
-char *emptynull(char *a) { return (a==NULL) ? "" : a;}
+gchar *emptynull(gchar *a) { return (a==NULL) ? "" : a;}
 
 /* Creates and initialises a main_view */
 MainView* interface_main_view_new( AppData *data ) {
@@ -263,7 +263,8 @@ void show_rec(MainView *main, rec *r, gboolean create) {
 /*	gtk_button_set_image(GTK_BUTTON(rec_win->edit_button), GTK_STOCK_EDIT); */
 #if MAEMO_VERSION_MAJOR < 5
 	gtk_dialog_add_button(GTK_DIALOG(rec_win->dialog), GTK_STOCK_CANCEL, GTK_RESPONSE_CANCEL);
-	g_object_set(rec_win->dialog, "content-area-border", 1, "button_spacing", 20, NULL);
+	// "content-area-border", 1 : Bug 9163
+	g_object_set(rec_win->dialog, "button_spacing", 20, NULL);
 #endif
     /*  where's "button-spacing", "content-area-border", "action_area_border" ? - not in scratchbox, maybe on n800 */
 	g_signal_connect(rec_win->dialog, "response", G_CALLBACK ( callback_rec_response), main);
@@ -326,6 +327,70 @@ void show_rec(MainView *main, rec *r, gboolean create) {
 	interface_set_rec_editable(rec_win, FALSE);
 }
 
+gint interface_getXmlFormat(MainView *main, gint xmlFormat) {
+	GtkWidget *dialog;
+#if MAEMO_VERSION_MAJOR < 5
+	GtkWidget *table;
+	GtkWidget *combo;
+#endif
+	gint res = -1;
+	
+	GtkWidget *selector = NULL;
+	gint i = 0;
+	
+	const gchar* XML_IMPORTS[PWSAFE_NB_XML_IMPORT] = {"KeePassX", "FPM2"};
+
+	if (xmlFormat < 0 || xmlFormat >= PWSAFE_NB_XML_IMPORT) {
+		xmlFormat = 0;
+	}
+	
+#if MAEMO_VERSION_MAJOR < 5
+	dialog = gtk_dialog_new_with_buttons(_("Select XML Import format"), 
+													GTK_WINDOW(main->data->main_view), 
+													GTK_DIALOG_MODAL | GTK_DIALOG_DESTROY_WITH_PARENT | GTK_DIALOG_NO_SEPARATOR, 
+													GTK_STOCK_OK,
+													GTK_RESPONSE_OK,
+													GTK_STOCK_CANCEL,
+													GTK_RESPONSE_REJECT,
+													NULL);
+	table = gtk_table_new(1, 2, TRUE);
+
+	gtk_container_add(GTK_CONTAINER(GTK_DIALOG(dialog)->vbox), table);
+
+	gtk_table_attach_defaults(GTK_TABLE(table), gtk_label_new(_("format")), 0, 1, 0, 1);
+	combo=gtk_combo_box_new_text();
+	gtk_table_attach_defaults(GTK_TABLE(table), combo, 1, 2, 0, 1);
+	
+	// Fill the combo
+	for (i = 0; i < PWSAFE_NB_XML_IMPORT; i++) {
+		gtk_combo_box_append_text(GTK_COMBO_BOX(combo), XML_IMPORTS[i]);
+	}
+	gtk_combo_box_set_active(GTK_COMBO_BOX(combo), xmlFormat);
+	
+#else
+	dialog = hildon_picker_dialog_new(GTK_WINDOW(main->data->main_view));
+	selector=hildon_touch_selector_new_text();
+	hildon_picker_dialog_set_selector(HILDON_PICKER_DIALOG(dialog), HILDON_TOUCH_SELECTOR(selector));
+	// Fill the combo
+	for (i = 0; i < PWSAFE_NB_XML_IMPORT; i++) {
+		hildon_touch_selector_append_text(HILDON_TOUCH_SELECTOR(selector), XML_IMPORTS[i]);
+	}
+	hildon_touch_selector_set_active(HILDON_TOUCH_SELECTOR(selector), 0, xmlFormat);
+	
+	gtk_window_set_title(GTK_WINDOW(dialog), _("Select XML Import format"));
+#endif
+	gtk_widget_show_all(dialog);
+	if (gtk_dialog_run(GTK_DIALOG(dialog)) == GTK_RESPONSE_OK) {
+#if MAEMO_VERSION_MAJOR < 5
+		res = gtk_combo_box_get_active(GTK_COMBO_BOX(combo));
+#else
+		res = hildon_touch_selector_get_active(HILDON_TOUCH_SELECTOR(selector), 0);
+#endif
+	}
+	gtk_widget_destroy( dialog );
+	return res;
+}
+
 void empty_treeView(MainView *main) {
 	 gtk_tree_store_clear(main->store);
 }
@@ -527,6 +592,7 @@ static void create_menu( MainView *main ) {
 	main->save_item = gtk_menu_item_new_with_label ( _("Save") );
 	main->saveas_item = gtk_menu_item_new_with_label ( _("Save As...") );
 	main->export_item = gtk_menu_item_new_with_label ( _("Export...") );
+	main->import_xml_item = gtk_menu_item_new_with_label ( _("Import XML...") );
 	
 	main->fullscreen_item = gtk_menu_item_new_with_label ( _("Full Screen") );
 	main->add_item = gtk_menu_item_new_with_label ( _("Add Entry") );
@@ -543,6 +609,7 @@ static void create_menu( MainView *main ) {
 	gtk_menu_append( GTK_MENU(file_menu), main->save_item );
 	gtk_menu_append( GTK_MENU(file_menu), main->saveas_item );
 	gtk_menu_append( GTK_MENU(file_menu), main->export_item );
+	gtk_menu_append( GTK_MENU(file_menu), main->import_xml_item );
  
 	gtk_menu_append( GTK_MENU(main_menu), main->add_item );
 	gtk_menu_append( GTK_MENU(main_menu), main->change_password );
@@ -562,6 +629,7 @@ static void create_menu( MainView *main ) {
 	g_signal_connect( G_OBJECT( main->save_item ), "activate",  G_CALLBACK ( callback_file_save), main );
 	g_signal_connect( G_OBJECT( main->saveas_item ), "activate",  G_CALLBACK ( callback_file_saveas), main );
 	g_signal_connect( G_OBJECT( main->export_item ), "activate",  G_CALLBACK ( callback_export), main );
+	g_signal_connect( G_OBJECT( main->import_xml_item ), "activate",  G_CALLBACK ( callback_import_xml), main );
 	g_signal_connect( G_OBJECT( main->add_item ), "activate",  G_CALLBACK ( callback_add_entry), main );
 	g_signal_connect( G_OBJECT( main->change_password ), "activate",  G_CALLBACK ( callback_change_password), main );
 	g_signal_connect( G_OBJECT( main->fullscreen_item ), "activate",  G_CALLBACK ( callback_fullscreen ), main );
@@ -579,6 +647,7 @@ static void create_menu( MainView *main ) {
 	main->save_item = add_menu_item (main_menu, _("Save"), G_CALLBACK ( callback_file_save), main );
 	main->saveas_item = add_menu_item (main_menu, _("Save As..."), G_CALLBACK ( callback_file_saveas), main );
 	main->export_item = add_menu_item (main_menu, _("Export..."), G_CALLBACK ( callback_export), main );
+	main->import_xml_item = add_menu_item (main_menu, _("Import XML..."), G_CALLBACK ( callback_import_xml), main );
 	
 	main->change_password = add_menu_item (main_menu, _("Change Password"), G_CALLBACK ( callback_change_password), main );
 
@@ -615,6 +684,7 @@ void interface_show_state(MainView *main) {
     	interface_show_item(main->save_item, fopen);
     	interface_show_item(main->saveas_item, fopen);
         interface_show_item(main->export_item, fopen);
+        interface_show_item(main->import_xml_item, fopen);
     	interface_show_item(main->change_password, fopen);
 	interface_show_item(main->add_item, fopen);
 	
