@@ -40,7 +40,9 @@
 
 #include <src/appdata.h>
 
-#define _(String) gettext(String)
+#include <locale.h>
+#include <glib/gi18n.h>
+
 
 /* confirmation responses */
 #define CONFRESP_YES 1
@@ -75,6 +77,12 @@ typedef enum {
 	N_COLUMNS
 } PwsafeColumns;
 
+typedef enum {
+	PWSAFE_KEEPASSX = 0,
+	PWSAFE_FPM2,
+	PWSAFE_NB_XML_IMPORT
+} PwsafeXmlImport;
+
 typedef struct RecWindow {
 	rec *rec;
 	gboolean editable;
@@ -113,6 +121,7 @@ struct _MainView
 	GtkWidget *save_item;
 	GtkWidget *saveas_item;
     GtkWidget *export_item;
+    GtkWidget *import_xml_item;
 	GtkWidget *view_item;
 	GtkWidget *add_item;
 	GtkWidget *change_password;
@@ -161,7 +170,8 @@ typedef struct PasswordUI {
 /* Publics: */
 MainView* interface_main_view_new( AppData* data );
 void interface_main_view_destroy( MainView* main );
-char* interface_file_chooser( MainView* main, GtkFileChooserAction action );
+gchar* interface_file_chooser( MainView* main, GtkFileChooserAction action);
+gint interface_getXmlFormat(MainView *main, gint xmlFormat);
 PangoFontDescription* interface_font_chooser( MainView * main );
 gint interface_yes_no_note(MainView * main, gchar *title);
 void interface_error( PwsafeError me, MainView *main );
@@ -172,7 +182,7 @@ void empty_treeView(MainView *main);
 void unshow_rec(MainView *main);
 gchar *get_password(MainView *main, gchar *caption, gint pwdDlgType);
 void interface_show_state(MainView *main);
-char *emptynull(char *a);
+gchar *emptynull(gchar *a);
 void interface_fullscreen(MainView *mainview);
 void interface_set_rec_editable(RecWindow* rec_win, gboolean editable);
 void interfaceCallLastItem(MainView *mainView) ;
